no_creds_available: Handle missing API key without throwing an error for unit...

View source: R/aaa.R

no_creds_availableR Documentation

Handle missing API key without throwing an error for unit testing purposes

Description

Handle missing API key without throwing an error for unit testing purposes

Usage

no_creds_available(api_key = Sys.getenv("FDIC_API_KEY"))

Arguments

api_key

(String) The API key for authenticating against the FDIC API

Details

Intended for internal use.

Value

(Logical) FALSE if a non-empty api_key has been supplied; otherwise TRUE.


fdic documentation built on Sept. 12, 2026, 5:09 p.m.