| get_summary | R Documentation |
Queries the /summary endpoint of the FDIC BankFind Suite API,
returning aggregate data by bank type, state, quarter, and year
for FDIC-insured financial institutions.
get_summary(
api_key = Sys.getenv("FDIC_API_KEY"),
filters = NULL,
fields = NULL,
sort_by = NULL,
descending = FALSE,
limit = 10000
)
api_key |
(String) Your FDIC API key. Required: the FDIC does not
accept unauthenticated requests. Defaults to the value of the
|
filters |
(String) An optional Elasticsearch query string to filter results. All field names and values must be uppercase. |
fields |
(String or Character vector) Fields to include in the response.
An |
sort_by |
(String) Field name to sort results by. Defaults to the API default sort order for this endpoint. |
descending |
(Logical) Should results be sorted in descending order?
Only applies when |
limit |
(Integer) Number of records to return. Must be between 1 and 10,000. Defaults to 10,000. |
A tibble containing historic aggregate financial and structure data regarding financial institutions, with one row per quarter and year.
# Return summary data for each bank type, state, quarter, and year
suppressMessages(get_summary(
fields = c("ASSET", "BANKS", "BRANCHES", "CALLYM", "NETINC"),
limit = 5
))
# Return summary data sorted by reporting period descending
suppressMessages(get_summary(
fields = c("ASSET", "BANKS", "CALLYM", "YEAR"),
sort_by = "CALLYM",
descending = TRUE,
limit = 5
))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.